@@ -6,6 +6,9 @@
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 
+#define GETTEXT_PACKAGE "mssh"
+#include <glib/gi18n-lib.h>
+
 #include "mssh-terminal.h"
 #include "mssh-pref.h"
 #include "mssh-gconf.h"
@@ -265,10 +268,15 @@ static gboolean mssh_window_session_close(gpointer data)
     if(idx == -1)
     {
         fprintf(stderr,
-            "mssh: Fatal Error: Can't find terminal to remove!\n");
+            _("mssh: Fatal Error: Can't find terminal to remove!\n"));
     }
     else
     {
+        /* set the focus on the entry only if the terminal closed has it */
+        if ( gtk_window_get_focus(GTK_WINDOW(data_pair->window)) == GTK_WIDGET(data_pair->terminal) ) {
+            gtk_window_set_focus(GTK_WINDOW(data_pair->window), GTK_WIDGET(data_pair->window->global_entry));
+        }
+
         gtk_widget_destroy(data_pair->terminal->menu_item);
 
         gtk_container_remove(GTK_CONTAINER(data_pair->window->grid),
@@ -278,8 +286,6 @@ static gboolean mssh_window_session_close(gpointer data)
 
         mssh_window_relayout(data_pair->window);
 
-        /* set the focus on the entry */
-        gtk_window_set_focus(GTK_WINDOW(data_pair->window), GTK_WIDGET(data_pair->window->global_entry));
     }
 
     if(data_pair->window->terminals->len == 0 &&
@@ -398,8 +404,8 @@ void mssh_window_relayout(MSSHWindow *window)
         }
 
         /* Set margins to terminal widget */
-        gtk_widget_set_margin_left(GTK_WIDGET(terminal), 1);
-        gtk_widget_set_margin_right(GTK_WIDGET(terminal), 1);
+        gtk_widget_set_margin_start(GTK_WIDGET(terminal), 1);
+        gtk_widget_set_margin_end(GTK_WIDGET(terminal), 1);
         gtk_widget_set_margin_top(GTK_WIDGET(terminal), 1);
         gtk_widget_set_margin_bottom(GTK_WIDGET(terminal), 1);
 
@@ -470,20 +476,16 @@ static void mssh_window_init(MSSHWindow* window)
     GtkWidget *file_menu = gtk_menu_new();
     GtkWidget *edit_menu = gtk_menu_new();
 
-    GtkWidget *file_item = gtk_menu_item_new_with_label("File");
-    GtkWidget *edit_item = gtk_menu_item_new_with_label("Edit");
-    GtkWidget *server_item = gtk_menu_item_new_with_label("Servers");
-    GtkWidget *command_item = gtk_menu_item_new_with_label("Commands");
+    GtkWidget *file_item = gtk_menu_item_new_with_label(_("File"));
+    GtkWidget *edit_item = gtk_menu_item_new_with_label(_("Edit"));
+    GtkWidget *server_item = gtk_menu_item_new_with_label(_("Servers"));
+    GtkWidget *command_item = gtk_menu_item_new_with_label(_("Commands"));
 
-    GtkWidget *file_quit = gtk_image_menu_item_new_from_stock(
-        GTK_STOCK_QUIT, NULL);
-    GtkWidget *file_sendhost = gtk_image_menu_item_new_with_label(
-        "Send hostname");
-    GtkWidget *file_add = gtk_menu_item_new_with_label(
-        "Add session");
+    GtkWidget *file_quit = gtk_menu_item_new_with_mnemonic(_("_Quit"));
+    GtkWidget *file_sendhost = gtk_menu_item_new_with_label(_("Send hostname"));
+    GtkWidget *file_add = gtk_menu_item_new_with_label(_("Add session"));
 
-    GtkWidget *edit_pref = gtk_image_menu_item_new_from_stock(
-        GTK_STOCK_PREFERENCES, NULL);
+    GtkWidget *edit_pref = gtk_menu_item_new_with_mnemonic(_("_Edit"));
 
     GtkAccelGroup *accel = gtk_accel_group_new();
 
@@ -813,7 +815,7 @@ static void mssh_window_add(GtkWidget *widget, gpointer data)
     content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
     /* label for text */
-    label = gtk_label_new ("Add new session with hostname: ");
+    label = gtk_label_new (_("Add new session with hostname: "));
 
     /* Add the label and entry, and show everything we've added to the dialog */
     new_session_entry = gtk_entry_new();
@@ -823,8 +825,8 @@ static void mssh_window_add(GtkWidget *widget, gpointer data)
     gtk_container_add (GTK_CONTAINER (content_area), label);
     gtk_container_add (GTK_CONTAINER (content_area), new_session_entry);
     /* add two buttons */
-    button_add = gtk_dialog_add_button(GTK_DIALOG(dialog), "Add", GTK_RESPONSE_ACCEPT);
-    gtk_dialog_add_button(GTK_DIALOG(dialog), "Cancel", GTK_RESPONSE_CANCEL);
+    button_add = gtk_dialog_add_button(GTK_DIALOG(dialog), _("Add"), GTK_RESPONSE_ACCEPT);
+    gtk_dialog_add_button(GTK_DIALOG(dialog), _("Cancel"), GTK_RESPONSE_CANCEL);
     /* make the add button the default */
     gtk_widget_grab_default(button_add);
     /* set dialog properties (modal, etc) */
@@ -832,7 +834,7 @@ static void mssh_window_add(GtkWidget *widget, gpointer data)
     gtk_window_set_destroy_with_parent(GTK_WINDOW(dialog), TRUE);
     gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(window));
     /* set it's title */
-    gtk_window_set_title(GTK_WINDOW(dialog), "Add new session");
+    gtk_window_set_title(GTK_WINDOW(dialog), _("Add new session"));
 
     /* catch the activate signal (hitting enter) */
     g_signal_connect(G_OBJECT(new_session_entry), "activate",
